module NumberSuffixData exposing (alphabetic, longScale, longScaleShort, standard, standardShort)

-- pasted from https://github.com/erosson/swarm-numberformat/blob/master/static/standard-suffixes.json

import Array


aToZ =
    List.range (Char.toCode 'a') (Char.toCode 'z') |> List.map Char.fromCode


aaToZz =
    aToZ
        |> List.concatMap (\first -> aToZ |> List.map (\last -> String.fromList [ first, last ]))


alphabetic =
    Array.append
        (standardShort |> Array.slice 0 5)
        (Array.fromList aaToZz)


standard =
    Array.fromList
        [ ""
        , " thousand"
        , " million"
        , " billion"
        , " trillion"
        , " quadrillion"
        , " quintillion"
        , " sextillion"
        , " septillion"
        , " octillion"
        , " nonillion"
        , " decillion"
        , " undecillion"
        , " duodecillion"
        , " tredecillion"
        , " quattuordecillion"
        , " quinquadecillion"
        , " sedecillion"
        , " septendecillion"
        , " octodecillion"
        , " novendecillion"
        , " vigintillion"
        , " unvigintillion"
        , " duovigintillion"
        , " tresvigintillion"
        , " quattuorvigintillion"
        , " quinquavigintillion"
        , " sesvigintillion"
        , " septemvigintillion"
        , " octovigintillion"
        , " novemvigintillion"
        , " trigintillion"
        , " untrigintillion"
        , " duotrigintillion"
        , " trestrigintillion"
        , " quattuortrigintillion"
        , " quinquatrigintillion"
        , " sestrigintillion"
        , " septentrigintillion"
        , " octotrigintillion"
        , " noventrigintillion"
        , " quadragintillion"
        , " unquadragintillion"
        , " duoquadragintillion"
        , " tresquadragintillion"
        , " quattuorquadragintillion"
        , " quinquaquadragintillion"
        , " sesquadragintillion"
        , " septenquadragintillion"
        , " octoquadragintillion"
        , " novenquadragintillion"
        , " quinquagintillion"
        , " unquinquagintillion"
        , " duoquinquagintillion"
        , " tresquinquagintillion"
        , " quattuorquinquagintillion"
        , " quinquaquinquagintillion"
        , " sesquinquagintillion"
        , " septenquinquagintillion"
        , " octoquinquagintillion"
        , " novenquinquagintillion"
        , " sexagintillion"
        , " unsexagintillion"
        , " duosexagintillion"
        , " tresexagintillion"
        , " quattuorsexagintillion"
        , " quinquasexagintillion"
        , " sesexagintillion"
        , " septensexagintillion"
        , " octosexagintillion"
        , " novensexagintillion"
        , " septuagintillion"
        , " unseptuagintillion"
        , " duoseptuagintillion"
        , " treseptuagintillion"
        , " quattuorseptuagintillion"
        , " quinquaseptuagintillion"
        , " seseptuagintillion"
        , " septenseptuagintillion"
        , " octoseptuagintillion"
        , " novenseptuagintillion"
        , " octogintillion"
        , " unoctogintillion"
        , " duooctogintillion"
        ]


standardShort =
    Array.fromList
        [ ""
        , "K"
        , "M"
        , "B"
        , "T"
        , "Qa"
        , "Qi"
        , "Sx"
        , "Sp"
        , "Oc"
        , "No"
        , "Dc"
        , "UDc"
        , "DDc"
        , "TDc"
        , "QaDc"
        , "QiDc"
        , "SxDc"
        , "SpDc"
        , "ODc"
        , "NDc"
        , "Vi"
        , "UVi"
        , "DVi"
        , "TVi"
        , "QaVi"
        , "QiVi"
        , "SxVi"
        , "SpVi"
        , "OVi"
        , "NVi"
        , "Tg"
        , "UTg"
        , "DTg"
        , "TTg"
        , "QaTg"
        , "QiTg"
        , "SxTg"
        , "SpTg"
        , "OTg"
        , "NTg"
        , "Qd"
        , "UQd"
        , "DQd"
        , "TQd"
        , "QaQd"
        , "QiQd"
        , "SxQd"
        , "SpQd"
        , "OQd"
        , "NQd"
        , "Qq"
        , "UQq"
        , "DQq"
        , "TQq"
        , "QaQq"
        , "QiQq"
        , "SxQq"
        , "SpQq"
        , "OQq"
        , "NQq"
        , "Sg"
        , "USg"
        , "DSg"
        , "TSg"
        , "QaSg"
        , "QiSg"
        , "SxSg"
        , "SpSg"
        , "OSg"
        , "NSg"
        , "St"
        , "USt"
        , "DSt"
        , "TSt"
        , "QaSt"
        , "QiSt"
        , "SxSt"
        , "SpSt"
        , "OSt"
        , "NSt"
        , "Og"
        , "UOg"
        , "DOg"
        , "TOg"
        , "QaOg"
        , "QiOg"
        , "SxOg"
        , "SpOg"
        , "OOg"
        , "NOg"
        ]


longScale =
    Array.fromList
        [ ""
        , " thousand"
        , " million"
        , " milliard"
        , " billion"
        , " billiard"
        , " trillion"
        , " trilliard"
        , " quadrillion"
        , " quadrilliard"
        , " quintillion"
        , " quintilliard"
        , " sextillion"
        , " sextilliard"
        , " septillion"
        , " septilliard"
        , " octillion"
        , " octilliard"
        , " nonillion"
        , " nonilliard"
        , " decillion"
        , " decilliard"
        , " undecillion"
        , " undecilliard"
        , " duodecillion"
        , " duodecilliard"
        , " tredecillion"
        , " tredecilliard"
        , " quattuordecillion"
        , " quattuordecilliard"
        , " quinquadecillion"
        , " quinquadecilliard"
        , " sedecillion"
        , " sedecilliard"
        , " septendecillion"
        , " septendecilliard"
        , " octodecillion"
        , " octodecilliard"
        , " novendecillion"
        , " novendecilliard"
        , " vigintillion"
        , " vigintilliard"
        , " unvigintillion"
        , " unvigintilliard"
        , " duovigintillion"
        , " duovigintilliard"
        , " tresvigintillion"
        , " tresvigintilliard"
        , " quattuorvigintillion"
        , " quattuorvigintilliard"
        , " quinquavigintillion"
        , " quinquavigintilliard"
        , " sesvigintillion"
        , " sesvigintilliard"
        , " septemvigintillion"
        , " septemvigintilliard"
        , " octovigintillion"
        , " octovigintilliard"
        , " novemvigintillion"
        , " novemvigintilliard"
        , " trigintillion"
        , " trigintilliard"
        , " untrigintillion"
        , " untrigintilliard"
        , " duotrigintillion"
        , " duotrigintilliard"
        , " trestrigintillion"
        , " trestrigintilliard"
        , " quattuortrigintillion"
        , " quattuortrigintilliard"
        , " quinquatrigintillion"
        , " quinquatrigintilliard"
        , " sestrigintillion"
        , " sestrigintilliard"
        , " septentrigintillion"
        , " septentrigintilliard"
        , " octotrigintillion"
        , " octotrigintilliard"
        , " noventrigintillion"
        , " noventrigintilliard"
        , " quadragintillion"
        , " quadragintilliard"
        , " unquadragintillion"
        , " unquadragintilliard"
        ]


longScaleShort =
    Array.fromList
        [ ""
        , "K"
        , "M"
        , "Md"
        , "B"
        , "Bd"
        , "T"
        , "Td"
        , "Qa"
        , "Qad"
        , "Qi"
        , "Qid"
        , "Sx"
        , "Sxd"
        , "Sp"
        , "Spd"
        , "Oc"
        , "Od"
        , "No"
        , "Nd"
        , "Dc"
        , "Dd"
        , "UDc"
        , "UDd"
        , "DDc"
        , "DDd"
        , "TDc"
        , "TDd"
        , "QaDc"
        , "QaDd"
        , "QiDc"
        , "QiDd"
        , "SxDc"
        , "SxDd"
        , "SpDc"
        , "SpDd"
        , "ODc"
        , "ODd"
        , "NDc"
        , "NDd"
        , "Vi"
        , "Vd"
        , "UVi"
        , "UVd"
        , "DVi"
        , "DVd"
        , "TVi"
        , "TVd"
        , "QaVi"
        , "QaVd"
        , "QiVi"
        , "QiVd"
        , "SxVi"
        , "SxVd"
        , "SpVi"
        , "SpVd"
        , "OVi"
        , "OVd"
        , "NVi"
        , "NVd"
        , "Tg"
        , "TD"
        , "UTg"
        , "UTD"
        , "DTg"
        , "DTD"
        , "TTg"
        , "TTD"
        , "QaTg"
        , "QaTD"
        , "QiTg"
        , "QiTD"
        , "SxTg"
        , "SxTD"
        , "SpTg"
        , "SpTD"
        , "OTg"
        , "OTD"
        , "NTg"
        , "NTD"
        , "Qd"
        , "QD"
        , "UQd"
        , "UQD"
        , "DQd"
        , "DQD"
        , "TQd"
        , "TQD"
        , "QaQd"
        , "QaQD"
        ]
